diff --git a/README.md b/README.md
index 0305cbb6c..69c6d698a 100644
--- a/README.md
+++ b/README.md
@@ -1,10 +1,14 @@
# Project: Jargon-core API
+
### Date: 07/05/2018
### Release Version: 4.3.0.0-RELEASE
### git tag: 4.3.0.0-RELEASE
## News
+4.2.3 Compatability and maintenance
+for milestone: https://github.com/DICE-UNC/jargon/milestone/23
+>>>>>>> origin/4-2-stable
https://github.com/DICE-UNC/jargon/milestone/24
diff --git a/jargon-core/pom.xml b/jargon-core/pom.xml
index 70984b08e..405e01cf5 100644
--- a/jargon-core/pom.xml
+++ b/jargon-core/pom.xml
@@ -3,7 +3,6 @@
org.irods
jargon
-
4.3.0.0-SNAPSHOT
4.0.0
diff --git a/jargon-core/src/main/java/org/irods/jargon/core/query/IRODSGenQueryBuilder.java b/jargon-core/src/main/java/org/irods/jargon/core/query/IRODSGenQueryBuilder.java
index 0ba1e3339..2cc3b5789 100644
--- a/jargon-core/src/main/java/org/irods/jargon/core/query/IRODSGenQueryBuilder.java
+++ b/jargon-core/src/main/java/org/irods/jargon/core/query/IRODSGenQueryBuilder.java
@@ -260,21 +260,29 @@ public IRODSGenQueryBuilder addConditionAsMultiValueCondition(final RodsGenQuery
}
/*
- * Format the query based on the operator TODO: add handling for tables, in, etc
+ * Format the query based on the operator
*/
- if (operator == QueryConditionOperators.IN) {
- GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition
-
- .instanceForIn(rodsGenQueryEnumValue.getName(), SelectFieldSource.DEFINED_QUERY_FIELD,
- String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
+ if (operator == QueryConditionOperators.IN || operator == QueryConditionOperators.NOT_IN
+ || operator == QueryConditionOperators.NOT_BETWEEN || operator == QueryConditionOperators.BETWEEN) {
+ GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition.instanceForMultiValue(
+ rodsGenQueryEnumValue.getName(), operator, SelectFieldSource.DEFINED_QUERY_FIELD,
+ String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
+ conditions.add(genQueryBuilderCondition);
+ } else if (operator == QueryConditionOperators.NOT_IN) {
+ GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition.instanceForMultiValue(
+ rodsGenQueryEnumValue.getName(), operator, SelectFieldSource.DEFINED_QUERY_FIELD,
+ String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
+ conditions.add(genQueryBuilderCondition);
+ } else if (operator == QueryConditionOperators.NOT_BETWEEN) {
+ GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition.instanceForMultiValue(
+ rodsGenQueryEnumValue.getName(), operator, SelectFieldSource.DEFINED_QUERY_FIELD,
+ String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
conditions.add(genQueryBuilderCondition);
-
} else if (operator == QueryConditionOperators.BETWEEN) {
- GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition
-
- .instanceForBetween(rodsGenQueryEnumValue.getName(), SelectFieldSource.DEFINED_QUERY_FIELD,
- String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
+ GenQueryBuilderCondition genQueryBuilderCondition = GenQueryBuilderCondition.instanceForMultiValue(
+ rodsGenQueryEnumValue.getName(), operator, SelectFieldSource.DEFINED_QUERY_FIELD,
+ String.valueOf(rodsGenQueryEnumValue.getNumericValue()), nonQuotedValues);
conditions.add(genQueryBuilderCondition);
} else {
throw new UnsupportedOperationException("query operator not yet supported:" + operator);
diff --git a/jargon-core/src/main/java/org/irods/jargon/core/query/QueryConditionOperators.java b/jargon-core/src/main/java/org/irods/jargon/core/query/QueryConditionOperators.java
index 6ff71f88f..abbd58291 100644
--- a/jargon-core/src/main/java/org/irods/jargon/core/query/QueryConditionOperators.java
+++ b/jargon-core/src/main/java/org/irods/jargon/core/query/QueryConditionOperators.java
@@ -12,8 +12,9 @@ public enum QueryConditionOperators {
NOT_EQUAL("<>"), LESS_THAN_OR_EQUAL_TO("<="), GREATER_THAN_OR_EQUAL_TO(">="), NOT_LIKE("not like"), SOUNDS_LIKE(
"sounds like"), SOUNDS_NOT_LIKE("sounds not like"), TABLE("table"), NUMERIC_LESS_THAN(
"n<"), NUMERIC_LESS_THAN_OR_EQUAL_TO("n<="), NUMERIC_GREATER_THAN_OR_EQUAL_TO(
- "n>="), NUMERIC_GREATER_THAN("n>"), NUMERIC_EQUAL("n="), EQUAL(
- "="), LESS_THAN("<"), GREATER_THAN(">"), IN("in"), BETWEEN("between"), LIKE("like");
+ "n>="), NUMERIC_GREATER_THAN("n>"), NUMERIC_EQUAL("n="), EQUAL("="), LESS_THAN(
+ "<"), GREATER_THAN(">"), IN("in"), NOT_IN(
+ "not in"), BETWEEN("between"), NOT_BETWEEN("not between"), LIKE("like");
private String operatorAsString;
@@ -88,9 +89,16 @@ public static QueryConditionOperators getOperatorFromStringValue(final String st
if (stringValue.equalsIgnoreCase(IN.operatorAsString)) {
return IN;
}
+
+ if (stringValue.equalsIgnoreCase(NOT_IN.operatorAsString)) {
+ return NOT_IN;
+ }
if (stringValue.equalsIgnoreCase(BETWEEN.operatorAsString)) {
return BETWEEN;
}
+ if (stringValue.equalsIgnoreCase(NOT_BETWEEN.operatorAsString)) {
+ return NOT_BETWEEN;
+ }
if (stringValue.equals(LIKE.operatorAsString)) {
return LIKE;
}
@@ -159,12 +167,20 @@ public static QueryConditionOperators getOperatorFromEnumStringValue(final Strin
if (stringValue.equalsIgnoreCase(GREATER_THAN.toString())) {
return GREATER_THAN;
}
+
+ if (stringValue.equalsIgnoreCase(NOT_IN.toString())) {
+ return NOT_IN;
+ }
if (stringValue.equalsIgnoreCase(IN.toString())) {
return IN;
}
if (stringValue.equalsIgnoreCase(BETWEEN.toString())) {
return BETWEEN;
}
+
+ if (stringValue.equalsIgnoreCase(NOT_BETWEEN.toString())) {
+ return NOT_BETWEEN;
+ }
if (stringValue.equals(LIKE.toString())) {
return LIKE;
}
diff --git a/jargon-core/src/test/java/org/irods/jargon/core/query/GenQueryFunctionalTests.java b/jargon-core/src/test/java/org/irods/jargon/core/query/GenQueryFunctionalTests.java
new file mode 100644
index 000000000..694dc1db7
--- /dev/null
+++ b/jargon-core/src/test/java/org/irods/jargon/core/query/GenQueryFunctionalTests.java
@@ -0,0 +1,228 @@
+package org.irods.jargon.core.query;
+
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Properties;
+
+import org.irods.jargon.core.connection.IRODSAccount;
+import org.irods.jargon.core.pub.IRODSFileSystem;
+import org.irods.jargon.core.pub.IRODSGenQueryExecutor;
+import org.irods.jargon.core.pub.io.IRODSFile;
+import org.irods.jargon.testutils.IRODSTestSetupUtilities;
+import org.irods.jargon.testutils.TestingPropertiesHelper;
+import org.irods.jargon.testutils.filemanip.ScratchFileUtils;
+import org.junit.After;
+import org.junit.AfterClass;
+import org.junit.Assert;
+import org.junit.BeforeClass;
+import org.junit.Test;
+
+/**
+ * Tests of various types of gen query
+ *
+ * @author conwaymc
+ *
+ */
+public class GenQueryFunctionalTests {
+
+ private static Properties testingProperties = new Properties();
+ private static TestingPropertiesHelper testingPropertiesHelper = new TestingPropertiesHelper();
+ private static ScratchFileUtils scratchFileUtils = null;
+ public static final String IRODS_TEST_SUBDIR_PATH = "GenQueryFunctionalTests";
+ private static IRODSTestSetupUtilities irodsTestSetupUtilities = null;
+ private static IRODSFileSystem irodsFileSystem;
+
+ @BeforeClass
+ public static void setUpBeforeClass() throws Exception {
+ TestingPropertiesHelper testingPropertiesLoader = new TestingPropertiesHelper();
+ testingProperties = testingPropertiesLoader.getTestProperties();
+ scratchFileUtils = new ScratchFileUtils(testingProperties);
+ scratchFileUtils.clearAndReinitializeScratchDirectory(IRODS_TEST_SUBDIR_PATH);
+ irodsTestSetupUtilities = new IRODSTestSetupUtilities();
+ irodsTestSetupUtilities.initializeIrodsScratchDirectory();
+ irodsTestSetupUtilities.initializeDirectoryForTest(IRODS_TEST_SUBDIR_PATH);
+ irodsFileSystem = IRODSFileSystem.instance();
+ }
+
+ @AfterClass
+ public static void tearDownAfterClass() throws Exception {
+ irodsFileSystem.closeAndEatExceptions();
+ }
+
+ @After
+ public void afterEach() throws Exception {
+ irodsFileSystem.closeAndEatExceptions();
+ }
+
+ /*
+ * query for file names in a parent dir where file name in a list
+ */
+ @Test
+ public void testQueryIn() throws Exception {
+ String subdirPrefix = "testQueryIn";
+ String fileName = "file";
+
+ IRODSAccount irodsAccount = testingPropertiesHelper.buildIRODSAccountFromTestProperties(testingProperties);
+
+ String targetIrodsCollection = testingPropertiesHelper.buildIRODSCollectionAbsolutePathFromTestProperties(
+ testingProperties, IRODS_TEST_SUBDIR_PATH + "/" + subdirPrefix);
+ IRODSFile irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount)
+ .instanceIRODSFile(targetIrodsCollection);
+ irodsFile.deleteWithForceOption();
+ irodsFile.mkdir();
+ String myTarget;
+
+ // put 5 files into the collection
+
+ myTarget = targetIrodsCollection + "/" + fileName + "a";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "b";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "c";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "d";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "e";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ /*
+ * create a query for file a,b,d
+ */
+
+ IRODSGenQueryExecutor irodsGenQueryExecutor = irodsFileSystem.getIRODSAccessObjectFactory()
+ .getIRODSGenQueryExecutor(irodsAccount);
+
+ IRODSGenQueryBuilder builder = new IRODSGenQueryBuilder(true, null);
+ List list = new ArrayList();
+ list.add(fileName + "a");
+ list.add(fileName + "b");
+ list.add(fileName + "d");
+
+ builder.addSelectAsGenQueryValue(RodsGenQueryEnum.COL_COLL_NAME)
+ .addSelectAsGenQueryValue(RodsGenQueryEnum.COL_DATA_NAME)
+ .addConditionAsMultiValueCondition(RodsGenQueryEnum.COL_DATA_NAME, QueryConditionOperators.IN, list)
+ .addConditionAsGenQueryField(RodsGenQueryEnum.COL_COLL_NAME, QueryConditionOperators.EQUAL,
+ targetIrodsCollection);
+
+ IRODSGenQueryFromBuilder query = builder.exportIRODSQueryFromBuilder(5000);
+
+ IRODSQueryResultSetInterface resultSet = irodsGenQueryExecutor.executeIRODSQuery(query, 0);
+ Assert.assertNotNull("no result", resultSet);
+
+ boolean founda = false;
+ boolean foundb = false;
+ boolean foundd = false;
+
+ for (IRODSQueryResultRow row : resultSet.getResults()) {
+ if (row.getColumn(1).equals(fileName + "a")) {
+ founda = true;
+ } else if (row.getColumn(1).equals(fileName + "b")) {
+ foundb = true;
+ } else if (row.getColumn(1).equals(fileName + "d")) {
+ foundd = true;
+ }
+ }
+
+ Assert.assertTrue("didnt find a", founda);
+ Assert.assertTrue("didnt find b", foundb);
+ Assert.assertTrue("didnt find d", foundd);
+
+ }
+
+ /*
+ * query for file names in a parent dir where file name in a list
+ */
+ @Test
+ public void testQueryNotIn() throws Exception {
+ String subdirPrefix = "testQueryNotIn";
+ String fileName = "file";
+
+ IRODSAccount irodsAccount = testingPropertiesHelper.buildIRODSAccountFromTestProperties(testingProperties);
+
+ String targetIrodsCollection = testingPropertiesHelper.buildIRODSCollectionAbsolutePathFromTestProperties(
+ testingProperties, IRODS_TEST_SUBDIR_PATH + "/" + subdirPrefix);
+ IRODSFile irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount)
+ .instanceIRODSFile(targetIrodsCollection);
+ irodsFile.deleteWithForceOption();
+ irodsFile.mkdir();
+ String myTarget;
+
+ // put 5 files into the collection
+
+ myTarget = targetIrodsCollection + "/" + fileName + "a";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "b";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "c";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "d";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ myTarget = targetIrodsCollection + "/" + fileName + "e";
+ irodsFile = irodsFileSystem.getIRODSFileFactory(irodsAccount).instanceIRODSFile(myTarget);
+ irodsFile.createNewFile();
+
+ /*
+ * create a query for file a,b,d
+ */
+
+ IRODSGenQueryExecutor irodsGenQueryExecutor = irodsFileSystem.getIRODSAccessObjectFactory()
+ .getIRODSGenQueryExecutor(irodsAccount);
+
+ IRODSGenQueryBuilder builder = new IRODSGenQueryBuilder(true, null);
+ List list = new ArrayList();
+ list.add(fileName + "a");
+ list.add(fileName + "b");
+ list.add(fileName + "d");
+
+ builder.addSelectAsGenQueryValue(RodsGenQueryEnum.COL_COLL_NAME)
+ .addSelectAsGenQueryValue(RodsGenQueryEnum.COL_DATA_NAME)
+ .addConditionAsMultiValueCondition(RodsGenQueryEnum.COL_DATA_NAME, QueryConditionOperators.NOT_IN, list)
+ .addConditionAsGenQueryField(RodsGenQueryEnum.COL_COLL_NAME, QueryConditionOperators.EQUAL,
+ targetIrodsCollection);
+
+ if (false) { // TODO: activate when https://github.com/DICE-UNC/jargon/issues/304 is resolved
+
+ IRODSGenQueryFromBuilder query = builder.exportIRODSQueryFromBuilder(5000);
+
+ IRODSQueryResultSetInterface resultSet = irodsGenQueryExecutor.executeIRODSQuery(query, 0);
+ Assert.assertNotNull("no result", resultSet);
+
+ boolean founda = false;
+ boolean foundb = false;
+ boolean foundd = false;
+
+ for (IRODSQueryResultRow row : resultSet.getResults()) {
+ if (row.getColumn(1).equals(fileName + "a")) {
+ founda = true;
+ } else if (row.getColumn(1).equals(fileName + "b")) {
+ foundb = true;
+ } else if (row.getColumn(1).equals(fileName + "d")) {
+ foundd = true;
+ }
+ }
+
+ Assert.assertTrue("found a", founda);
+ Assert.assertTrue("found b", foundb);
+ Assert.assertTrue("found d", foundd);
+ }
+
+ }
+
+}
diff --git a/jargon-core/src/test/java/org/irods/jargon/core/query/GenQuerySelectFieldTest.java b/jargon-core/src/test/java/org/irods/jargon/core/query/GenQuerySelectFieldTest.java
index cd82c919e..de6fde696 100644
--- a/jargon-core/src/test/java/org/irods/jargon/core/query/GenQuerySelectFieldTest.java
+++ b/jargon-core/src/test/java/org/irods/jargon/core/query/GenQuerySelectFieldTest.java
@@ -1,6 +1,5 @@
package org.irods.jargon.core.query;
-import org.irods.jargon.core.exception.JargonException;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;
@@ -23,19 +22,19 @@ public final void testInstanceRodsGenQueryEnumSelectFieldTypesSelectFieldSource(
Assert.assertNotNull("null instance", selectField);
}
- @Test(expected = JargonException.class)
+ @Test(expected = IllegalArgumentException.class)
public final void testInstanceNullRodsGenQueryEnum() throws Exception {
GenQuerySelectField.instance(null, GenQuerySelectField.SelectFieldTypes.FIELD,
GenQuerySelectField.SelectFieldSource.DEFINED_QUERY_FIELD);
}
- @Test(expected = JargonException.class)
+ @Test(expected = IllegalArgumentException.class)
public final void testInstanceNullSelectFieldType() throws Exception {
GenQuerySelectField.instance(RodsGenQueryEnum.COL_AUDIT_ACTION_ID, null,
GenQuerySelectField.SelectFieldSource.DEFINED_QUERY_FIELD);
}
- @Test(expected = JargonException.class)
+ @Test(expected = IllegalArgumentException.class)
public final void testInstanceNullSelectFieldSource() throws Exception {
GenQuerySelectField.instance(RodsGenQueryEnum.COL_AUDIT_ACTION_ID, GenQuerySelectField.SelectFieldTypes.FIELD,
null);
diff --git a/jargon-core/src/test/java/org/irods/jargon/core/unittest/IRODSQueryTests.java b/jargon-core/src/test/java/org/irods/jargon/core/unittest/IRODSQueryTests.java
index 6e04c0e7e..21fcdfc49 100644
--- a/jargon-core/src/test/java/org/irods/jargon/core/unittest/IRODSQueryTests.java
+++ b/jargon-core/src/test/java/org/irods/jargon/core/unittest/IRODSQueryTests.java
@@ -1,8 +1,7 @@
-/**
- *
- */
+
package org.irods.jargon.core.unittest;
+import org.irods.jargon.core.query.GenQueryFunctionalTests;
import org.irods.jargon.core.query.GenQuerySelectFieldTest;
import org.irods.jargon.core.query.IRODSGenQueryBuilderTest;
import org.irods.jargon.core.query.IRODSGenQueryFromBuilderTest;
@@ -16,9 +15,8 @@
@RunWith(Suite.class)
@Suite.SuiteClasses({ IRODSGenQueryTranslatorTest.class, GenQuerySelectFieldTest.class, TranslatedIRODSQueryTest.class,
- SimpleQueryTest.class, IRODSSimpleQueryResultSetTest.class, UserFilePermissionTest.class,
- IRODSGenQueryBuilderTest.class, IRODSGenQueryFromBuilderTest.class })
-
+ IRODSSimpleQueryResultSetTest.class, IRODSGenQueryFromBuilderTest.class, SimpleQueryTest.class,
+ UserFilePermissionTest.class, IRODSGenQueryBuilderTest.class, GenQueryFunctionalTests.class })
public class IRODSQueryTests {
}
diff --git a/jargon-data-utils/pom.xml b/jargon-data-utils/pom.xml
index c5662c1f3..d38cf1798 100644
--- a/jargon-data-utils/pom.xml
+++ b/jargon-data-utils/pom.xml
@@ -5,7 +5,6 @@
org.irods
jargon
-
4.3.0.0-SNAPSHOT
org.irods.jargon
diff --git a/jargon-pool/pom.xml b/jargon-pool/pom.xml
index 5db407f49..2a8caa6da 100644
--- a/jargon-pool/pom.xml
+++ b/jargon-pool/pom.xml
@@ -107,7 +107,7 @@
-
org.eclipse.m2e
diff --git a/jargon-ruleservice/pom.xml b/jargon-ruleservice/pom.xml
index 8e2cbbc2b..629564916 100644
--- a/jargon-ruleservice/pom.xml
+++ b/jargon-ruleservice/pom.xml
@@ -3,7 +3,6 @@
org.irods
jargon
-
4.3.0.0-SNAPSHOT
org.irods.jargon
diff --git a/jargon-ticket/pom.xml b/jargon-ticket/pom.xml
index 0fb698199..5f41f27ae 100644
--- a/jargon-ticket/pom.xml
+++ b/jargon-ticket/pom.xml
@@ -3,7 +3,6 @@
org.irods
jargon
-
4.3.0.0-SNAPSHOT
org.irods.jargon
diff --git a/jargon-user-profile/pom.xml b/jargon-user-profile/pom.xml
index 2f14bf451..425507e92 100644
--- a/jargon-user-profile/pom.xml
+++ b/jargon-user-profile/pom.xml
@@ -4,7 +4,6 @@
jargon
org.irods
-
4.3.0.0-SNAPSHOT
org.irods.jargon
diff --git a/jargon-user-tagging/pom.xml b/jargon-user-tagging/pom.xml
index 9451ab23e..9e69a2f3b 100644
--- a/jargon-user-tagging/pom.xml
+++ b/jargon-user-tagging/pom.xml
@@ -2,7 +2,6 @@
org.irods
jargon
-
4.3.0.0-SNAPSHOT
4.0.0
diff --git a/jargon-zipservice/pom.xml b/jargon-zipservice/pom.xml
index 11367c0cc..478d54a80 100644
--- a/jargon-zipservice/pom.xml
+++ b/jargon-zipservice/pom.xml
@@ -5,7 +5,6 @@
jargon
org.irods
-
4.3.0.0-SNAPSHOT
org.irods.jargon
diff --git a/pom.xml b/pom.xml
index 14cf2dd35..cadea98bd 100644
--- a/pom.xml
+++ b/pom.xml
@@ -148,8 +148,8 @@
-
diff --git a/jargon-core/src/main/java/org/irods/jargon/core/query/GenQueryBuilderCondition.java b/jargon-core/src/main/java/org/irods/jargon/core/query/GenQueryBuilderCondition.java
index 0a52610c1..3a62f89b8 100644
--- a/jargon-core/src/main/java/org/irods/jargon/core/query/GenQueryBuilderCondition.java
+++ b/jargon-core/src/main/java/org/irods/jargon/core/query/GenQueryBuilderCondition.java
@@ -19,11 +19,6 @@ class GenQueryBuilderCondition {
private final QueryConditionOperators operator;
private final String value;
- /*
- * (non-Javadoc)
- *
- * @see java.lang.Object#toString()
- */
@Override
public String toString() {
StringBuilder sb = new StringBuilder();
@@ -56,7 +51,7 @@ public String toString() {
* condition
* @param value
* {@code String} with the right hand side of the query condition
- * @return
+ * @return {@link GenQueryBuilderCondition}
*/
static GenQueryBuilderCondition instance(final String selectFieldColumnName,
final SelectFieldSource selectFieldSource, final String selectFieldNumericTranslation,
@@ -66,29 +61,7 @@ static GenQueryBuilderCondition instance(final String selectFieldColumnName,
operator, value);
}
- /**
- * Create a query condition for an 'BETWEEN' condition. Note that the individual
- * values for the BETWEEN are to be provided in an array without quotes, which
- * will be added during processing
- *
- * @param selectFieldColumnName
- * {@code String} with the column name
- * @param selectFieldSource
- * {@link SelectFieldSource} that reflects the type of field
- * @param selectFieldNumericTranslation
- * {@code String} with the numeric iRODS gen query protocol value
- * that maps to this field
- * @param valuesWithoutQuotes
- * {@code List} of in arguments, as non quoted strings
- * @return
- */
- static GenQueryBuilderCondition instanceForBetween(final String selectFieldColumnName,
- final SelectFieldSource selectFieldSource, final String selectFieldNumericTranslation,
- final List valuesWithoutQuotes) {
-
- if (valuesWithoutQuotes == null || valuesWithoutQuotes.isEmpty()) {
- throw new IllegalArgumentException("null or empty valueWithoutQuotes");
- }
+ private static String stackListValues(final List valuesWithoutQuotes) {
StringBuilder sb = new StringBuilder();
for (String value : valuesWithoutQuotes) {
@@ -98,15 +71,14 @@ static GenQueryBuilderCondition instanceForBetween(final String selectFieldColum
sb.append("' ");
}
-
- return new GenQueryBuilderCondition(selectFieldColumnName, selectFieldSource, selectFieldNumericTranslation,
- QueryConditionOperators.BETWEEN, sb.toString());
+ return sb.toString();
}
+
/**
* Create a query condition for an 'IN' condition. Note that the individual
* values for the IN are to be provided in an array without quotes, which will
* be added during processing
*
* @param selectFieldColumnName
* {@code String} with the column name
@@ -117,45 +89,28 @@ static GenQueryBuilderCondition instanceForBetween(final String selectFieldColum
* that maps to this field
* @param valuesWithoutQuotes
* {@code List} of in arguments, as non quoted strings
- * @return
+ * @return {@link GenQueryBuilderCondition}
*/
- static GenQueryBuilderCondition instanceForIn(final String selectFieldColumnName,
- final SelectFieldSource selectFieldSource, final String selectFieldNumericTranslation,
- final List valuesWithoutQuotes) {
+ static GenQueryBuilderCondition instanceForMultiValue(final String selectFieldColumnName,
+ final QueryConditionOperators operator, final SelectFieldSource selectFieldSource,
+ final String selectFieldNumericTranslation, final List valuesWithoutQuotes) {
if (valuesWithoutQuotes == null || valuesWithoutQuotes.isEmpty()) {
throw new IllegalArgumentException("null or empty valueWithoutQuotes");
}
- StringBuilder sb = new StringBuilder();
- sb.append('(');
- boolean first = true;
- for (String value : valuesWithoutQuotes) {
-
- if (!first) {
- sb.append(",");
+ /* between and not between need 2 vals */
+ if (operator == QueryConditionOperators.BETWEEN || operator == QueryConditionOperators.NOT_BETWEEN) {
+ if (valuesWithoutQuotes.size() != 2) {
+ throw new IllegalArgumentException("between type queries need two values");
}
- sb.append("'");
- sb.append(value);
- sb.append("'");
- first = false;
}
- sb.append(")");
-
return new GenQueryBuilderCondition(selectFieldColumnName, selectFieldSource, selectFieldNumericTranslation,
- QueryConditionOperators.IN, sb.toString());
+ operator, stackListValues(valuesWithoutQuotes));
}
- /**
- *
- * @param selectFieldColumnName
- * @param selectFieldSource
- * @param selectFieldNumericTranslation
- * @param operator
- * @param value
- */
private GenQueryBuilderCondition(final String selectFieldColumnName, final SelectFieldSource selectFieldSource,
final String selectFieldNumericTranslation, final QueryConditionOperators operator, final String value) {
this.selectFieldColumnName = selectFieldColumnName;
@@ -98,15 +71,14 @@ static GenQueryBuilderCondition instanceForBetween(final String selectFieldColum
/**
- * Create a query condition for an 'IN' condition. Note that the individual
- * values for the IN are to be provided in an array without quotes, which will
- * be added during processing
+ * Create a query condition for multi-value (BETWEEN, IN, etc) condition. Note
+ * that the individual values are to be provided in an array without quotes,
+ * which will be added during processing
*
* @param selectFieldColumnName